// Copyright (C) 2002 Neil Stevens <neil@qualityassistant.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
// THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name(s) of the author(s) shall not be
// used in advertising or otherwise to promote the sale, use or other dealings
// in this Software without prior written authorization from the author(s).

#ifndef KMEDIAPLAYERENGINE_H
#define KMEDIAPLAYERENGINE_H

#include <qobject.h>
#include <kurl.h>

namespace KMediaPlayer
{

/** A bare-bones media player engine
 *
 * Use this when you want to supply your own user interface, or do not need
 * a user interface at all.
 */
class Engine : public QObject
{
Q_OBJECT

public:
	Engine(QObject *parent = 0, const char *name = 0);
	virtual ~Engine(void);

public slots:
	virtual bool open(const KURL &file) = 0;
	virtual void pause(void) = 0;
	virtual void play(void) = 0;
	virtual void stop(void) = 0;

	virtual void seek(unsigned long msec) = 0;
public:
	virtual bool seekable(void) const = 0;
	virtual unsigned long position(void) const = 0;
	virtual bool hasLength(void) const = 0;
	virtual unsigned long length(void) const = 0;

public slots:
	void setLooping(bool);
public:
	bool looping(void) const;
signals:
	void loopingChange(bool);

public:
	enum State { Empty, Stop, Pause, Play };
	State state(void) const;
signals:
	void stateChange(State);

protected slots:
	void setState(State);

private:
	bool currentLooping;
	State currentState;

	struct Data;
	Data *d;
};

}

#endif
